# -*- coding: utf-8 -*-
"""
Seamless ImmutableModel for Django Models

Copyright:
Please see LICENSE and AUTHORS for more information.
"""

from models import ImmutableModel, CantDeleteImmutableException, PK_FIELD, UNDEFINED
from admin import ImmutableModelAdmin
